"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const visitor_1 = require("./visitor");
const path_1 = require("path");
const graphql_tag_1 = require("graphql-tag");
exports.plugin = (schema, documents, config) => {
    const allAst = graphql_1.concatAST(documents.reduce((prev, v) => {
        return [...prev, v.content];
    }, []));
    const operations = allAst.definitions.filter(d => d.kind === graphql_1.Kind.OPERATION_DEFINITION);
    if (operations.length === 0) {
        return '';
    }
    const allFragments = allAst.definitions.filter(d => d.kind === graphql_1.Kind.FRAGMENT_DEFINITION);
    const visitor = new visitor_1.ApolloAngularVisitor(allFragments, operations, config);
    const visitorResult = graphql_1.visit(allAst, { leave: visitor });
    return [
        visitor.getImports(),
        visitor.fragments,
        ...visitorResult.definitions.filter(t => typeof t === 'string')
    ].join('\n');
};
exports.addToSchema = graphql_tag_1.default `
  directive @NgModule(module: String!) on OBJECT | FIELD
  directive @namedClient(name: String!) on OBJECT | FIELD
`;
exports.validate = async (schema, documents, config, outputFile) => {
    if (path_1.extname(outputFile) !== '.ts') {
        throw new Error(`Plugin "apollo-angular" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map